
# Class: Namespaces




URI: [nwb_schema_language:Namespaces](https://w3id.org/p2p_ld/nwb-schema-language/Namespaces)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Namespace]<namespaces%200..*-++[Namespaces],[Namespace])](https://yuml.me/diagram/nofunky;dir:TB/class/[Namespace]<namespaces%200..*-++[Namespaces],[Namespace])

## Attributes


### Own

 * [namespaces](namespaces.md)  <sub>0..\*</sub>
     * Range: [Namespace](Namespace.md)
